/**
 * catrm, prompt option to cat a file before removing it.
**/
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "fcat.h"

enum OPTS {
	OPTS_NONE = 0x00,
	OPTS_INTERACTIVE = 0x01
};


int prompt(const char *fpath);
int cat(const char *fpath);
int rm(const char *fpath);
void usage(const char *name)
{
	printf("usage: %s [OPTIONS] [FILE]..\n", name);
	puts("");
	puts("prompt the option to remove and/or cat a file.");
	puts("");
	puts("options:");
	puts("\t-ni    non-interactive mode, cat each listed file and remove it.");
	puts("");
	exit(EXIT_SUCCESS);
}


int main(int argc, char *argv[])
{
	int opts = OPTS_INTERACTIVE, i;

	for (i = 1; i < argc; ++i) {
		if (!argv[i] || argv[i][0] != '-') continue;

		if (strcmp(argv[i], "-h") == 0)
			usage(argv[0]);
		else if (strcmp(argv[i], "-ni") == 0)
			opts &= ~OPTS_INTERACTIVE;
		else
			printf("unrecognised arg: '%s'", argv[i]);
		argv[i] = 0;
	}

	for (i = 1; i < argc; ++i) {
		if (!(opts & OPTS_INTERACTIVE)) {
			cat(argv[i]);
			rm(argv[i]);
		} else if (prompt(argv[i]) == 'y') {
			rm(argv[i]);
		}
	}

	return EXIT_SUCCESS;
}

int prompt(const char *fpath)
{
	int ret = 0;
	char input = 'c';

	while (ret == 0) {
		printf("remove file '%s' ([y]es/[n]o/[c]at)? ", fpath);
		input = fgetc(stdin);
		
		switch (input) {
			case 'y': ret = 'y'; break;
			case 'n': ret = 'n'; break;
			case 'c': ret = cat(fpath); break;
			default: break;
		}

		while (fgetc(stdin) != '\n');
	}

	return ret;
}

int cat(const char *fpath)
{
	FILE *f = 0;
	int ret = 0;
	
	if (!(f = fopen(fpath, "r"))) {
		perror("failed to open file");
		ret = -1;
	}
	if (fcat(f, stdout) < 0) {
		perror("fcat failed");
		ret = -1;
	}
	fclose(f);

	return ret;
}

int rm(const char *fpath)
{
	int ret = 0;
	
	if (remove(fpath) != 0) {
		perror("remove failed");
		ret = -1;
	}

	return ret;
}
